summaryrefslogtreecommitdiff
path: root/render/html.h
diff options
context:
space:
mode:
authorJohn Mark Bell <jmb@netsurf-browser.org>2011-03-10 23:08:34 +0000
committerJohn Mark Bell <jmb@netsurf-browser.org>2011-03-10 23:08:34 +0000
commit8f3ed71cbab75c6445a4f13e4e1bc8b768a452b1 (patch)
tree56ad8b2d2a1b28dcb99130508f28fbdd9b1e686a /render/html.h
parent02361309edbc5d2cbf1cd79e555ca6c6348b2920 (diff)
downloadnetsurf-8f3ed71cbab75c6445a4f13e4e1bc8b768a452b1.tar.gz
netsurf-8f3ed71cbab75c6445a4f13e4e1bc8b768a452b1.tar.bz2
Keep child objects of a HTML content in a list, instead of an array
svn path=/trunk/netsurf/; revision=11963
Diffstat (limited to 'render/html.h')
-rw-r--r--render/html.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/render/html.h b/render/html.h
index c06252a4f..ac91f97f0 100644
--- a/render/html.h
+++ b/render/html.h
@@ -85,6 +85,9 @@ typedef enum {
/** An object (<img>, <object>, etc.) in a CONTENT_HTML document. */
struct content_html_object {
+ struct content *parent; /**< Parent document */
+ struct content_html_object *next; /**< Next in chain */
+
struct hlcache_handle *content; /**< Content, or 0. */
struct box *box; /**< Node in box tree containing it. */
/** Pointer to array of permitted content_type, terminated by
@@ -157,10 +160,10 @@ struct content_html_data {
/**< Style selection context */
css_select_ctx *select_ctx;
- /** Number of entries in object. */
- unsigned int object_count;
- /** Objects. Each may be 0. */
- struct content_html_object *object;
+ /** Number of entries in object_list. */
+ unsigned int num_objects;
+ /** List of objects. */
+ struct content_html_object *object_list;
/** Forms, in reverse order to document. */
struct form *forms;
/** Hash table of imagemaps. */
@@ -178,8 +181,6 @@ struct content_html_data {
/** Content of type CONTENT_HTML containing this, or 0 if not an object
* within a page. */
struct content *page;
- /** Index in page->data.html.object, or 0 if not an object. */
- unsigned int index;
/** Box containing this, or 0 if not an object. */
struct box *box;
};